@@ -1,5 +1,3 @@
-#!/usr/bin/python
-
 # Hearts - john.py
 # Copyright 2006 Sander Marechal
 #
@@ -20,6 +18,6 @@
 from stock_ai import *
 
 class PlayerAI_Pauline(StockAI):
-	def __init__(self, direction, trick):
-		Player.__init__(self, direction, trick)
+	def __init__(self, direction, trick, score, rules):
+		Player.__init__(self, direction, trick, score, rules)
 		self.name = "Pauline"
