@@ -20,6 +20,7 @@
 #include <Python.h>
 #include "cfg.h"
 #include "cards.h"
+#include "player.h"
 
 /* Return the name of a card */
 gchar*	card_get_name(Card *card)
@@ -123,6 +124,9 @@ gint cards_get_points(GList *list)
 	{
 		Card* card = l->data;
 		
+		if (card == NULL)
+			continue;
+
 		if (card->suit == CARDS_HEARTS || (card->suit == CARDS_SPADES && card->rank == CARD_QUEEN))
 			point_cards ++;
 	}
@@ -139,6 +143,9 @@ gint cards_get_points(GList *list)
 	{
 		Card* card = l->data;
 		
+		if (card == NULL)
+			continue;
+
 		/* Hearts add points */
 		if (card->suit == CARDS_HEARTS)
 		{
@@ -351,7 +358,7 @@ GList* cards_hand_draw_selected(CardsHand *hand)
 
 void cards_hand_add(CardsHand *hand, GList *list)
 {
-	hand->list = g_list_concat(hand->list, list);
+	hand->list = g_list_concat(hand->list, g_list_copy(list));
 	cards_hand_sort(hand);
 }
 
