@@ -21,9 +21,9 @@
 #define CARDS_H
 
 #include <glib.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
-#include "gettext.h"
 #include "cards-image.h"
 
 enum 
