@@ -25,22 +25,31 @@
 /* The Config object holds all of the game's configuration settings */
 typedef struct _Config
 {
+	/* General configuration options. */
+	gchar *config_path;
+	gchar *config_file;
 	gint ruleset;
 	gboolean clubs_lead;
 	gboolean hearts_break;
 	gboolean no_blood;
+	gboolean queen_breaks_hearts;
+	gboolean show_scores;
 	gchar *north_ai;
 	gchar *east_ai;
 	gchar *west_ai;
 	gchar *card_style;
 	gchar *background_image;
 	gboolean background_tiled;
+
+	/* These options are only accessible from the commandline. */
+	gboolean show_cards;
 } Config;
 
 extern Config cfg;
 
 void config_load(void);
 void config_save(void);
+void config_publish(void);
 void config_free(void);
 
 #endif
