@@ -214,15 +214,7 @@ gboolean button_press_event(GtkWidget *widget, GdkEventButton *event)
 			/* see if we're done playing this trick */
 			if (game_trick.num_played == 4)
 			{
-				/* show the tricks to the AI's */
-				player_trick_end(player[NORTH]);
-				player_trick_end(player[EAST]);
-				player_trick_end(player[WEST]);
-				
 				/* start the next trick in this game */
-				game_hearts_broken = game_hearts_broken || trick_num_suit(&game_trick, CARDS_HEARTS);
-				game_trick_winner = trick_get_winner(&game_trick);
-				player_take_trick(player[game_trick_winner], &game_trick);
 				trick_reset(&game_trick);
 				
 				/* is this also the end of the round or game? */
@@ -243,14 +235,16 @@ gboolean button_press_event(GtkWidget *widget, GdkEventButton *event)
 				return TRUE;
 			}
 			
-			/* loop through the hand to find the active card */
+			/* loop through the hand to find the active card and make sure it's valid.
+			 * Apparently it's sometimes possible to play an invalid card. See bug #30.
+			 */
 			card = cards_hand_get_active(player[user]->hand);
-			if (card != NULL)
-				player_play_card(player[user], card);
-			else
+			if (card == NULL || !game_is_valid_card(card, player[user]->hand, &game_trick))
 				return TRUE;
 			
-			/* play random cards untill the trick is over */
+			player_play_card(player[user], card);
+			
+			/* play cards until the trick is over */
 			i = user;
 			while (game_trick.num_played < 4)
 			{
@@ -258,6 +252,20 @@ gboolean button_press_event(GtkWidget *widget, GdkEventButton *event)
 				player_play_card(player[i], player_play(player[i]));
 			}
 			
+			/* update the game status and score */
+			if ( cfg.queen_breaks_hearts )
+				game_hearts_broken = game_hearts_broken || ( trick_num_point_cards( &game_trick ) > 0 ) ;
+			else
+				game_hearts_broken = game_hearts_broken || trick_num_suit(&game_trick, CARDS_HEARTS);
+
+			game_trick_winner = trick_get_winner(&game_trick);
+			player_take_trick(player[game_trick_winner], &game_trick);
+			
+			/* show the tricks to the AI's */
+			player_trick_end(player[NORTH]);
+			player_trick_end(player[EAST]);
+			player_trick_end(player[WEST]);
+			
 			/* redraw the screen */
 			game_set_status(_("Click somewhere to continue the game."));
 			ui_draw_playingarea();
@@ -480,6 +488,15 @@ void on_clubs_lead_changed (GtkToggleButton *widget, gpointer *data)
 void on_hearts_break_changed (GtkToggleButton *widget, gpointer *data)
 {
 	cfg.hearts_break = gtk_toggle_button_get_active(widget);
+	gtk_widget_set_sensitive(glade_xml_get_widget(ui.xml, "queen_breaks_hearts"), cfg.hearts_break);
+
+	// Also update queen_breaks_hearts if hearts_broken is disabled
+	if (!cfg.hearts_break)
+	{
+		gtk_toggle_button_set_active(glade_xml_get_widget(ui.xml, "queen_breaks_hearts"), FALSE);
+		cfg.queen_breaks_hearts = FALSE;
+	}
+
 	game_new();
 }
 
@@ -490,6 +507,31 @@ void on_no_blood_changed (GtkToggleButton *widget, gpointer *data)
 	game_new();
 }
 
+/* update the queen_breaks_hearts config value */
+void on_queen_breaks_hearts_changed (GtkToggleButton *widget, gpointer *data)
+{
+	cfg.queen_breaks_hearts = gtk_toggle_button_get_active(widget);
+	game_new();
+}
+
+void on_show_scores_changed (GtkToggleButton *widget, gpointer *data)
+{
+	int i;
+	cfg.show_scores = gtk_toggle_button_get_active(widget);
+
+	if (!cfg.show_scores)
+	{
+		for (i = 0; i < 4; i++)
+		{
+			gchar *name = g_strconcat("<span foreground=\"white\"><b>", player[i]->name, "</b></span>", NULL);
+			pango_layout_set_markup(player[i]->layout, name, -1);
+			g_free(name);
+		}
+	}
+
+	ui_draw_playingarea();
+}
+
 /* load new north_ai */
 void on_north_ai_changed (GtkComboBox *widget, gpointer *data)
 {
