@@ -51,6 +51,8 @@ void on_ruleset_changed			(GtkComboBox *widget, 	  gpointer *data);
 void on_clubs_lead_changed		(GtkToggleButton *widget, gpointer *data);
 void on_hearts_break_changed	(GtkToggleButton *widget, gpointer *data);
 void on_no_blood_changed		(GtkToggleButton *widget, gpointer *data);
+void on_queen_breaks_hearts_changed	(GtkToggleButton *widget, gpointer *data);
+void on_show_scores_changed		(GtkToggleButton *widget, gpointer *data);
 void on_north_ai_changed		(GtkComboBox *widget, 	  gpointer *data);
 void on_east_ai_changed			(GtkComboBox *widget, 	  gpointer *data);
 void on_west_ai_changed			(GtkComboBox *widget, 	  gpointer *data);
