@@ -20,24 +20,10 @@
 #ifndef PLAYER_API_H
 #define PLAYER_API_H
 
-#include <glib.h>
-#include <lua.h>
-#include <lualib.h>
-#include <lauxlib.h>
+#include <Python.h>
 
-#include "cards.h"
-
-void stack_dump (lua_State *L);
-
-/* C functions that will get exposed to Lua */
-gint lua_trick_get_winner (lua_State *state);
-gint lua_trick_get_trump (lua_State *state);
-gint lua_trick_get_num_played(lua_State *state);
-gint lua_trick_get_score (lua_State *state);
-gint lua_is_valid_card (lua_State *state);
-
-/* Functions for manipulating states */
-lua_State* lua_state_init(void);
-Card* lua_pop_card(lua_State *state);
+void python_start(void);
+void python_stop(void);
+PyMODINIT_FUNC initplayer_api(void);
 
 #endif /* PLAYER_API_H */
