@@ -30,6 +30,8 @@ Player* player_new(gint direction, gboolean show_faces, gchar *script, Trick *tr
 	/* create the player with default values */
 	Player *player;
 	player = g_new(Player, 1);
+	player->direction = direction;
+	player->score_round = 0;
 	player->score_total = 0;
 	player->trick = trick;
 	player->name = NULL;
@@ -47,7 +49,12 @@ Player* player_new(gint direction, gboolean show_faces, gchar *script, Trick *tr
 	/* Create a new player AI instance by calling the classname in Python */
 	gchar *class = (script ? script : "StockAI");
 	
-	player_args = Py_BuildValue("(iO)", direction, PyDict_GetItemString(dict, "trick"));
+	player_args = Py_BuildValue("(iOOO)",
+		direction, PyDict_GetItemString(dict, "trick"),
+		PyDict_GetItemString(dict, "score"),
+		PyDict_GetItemString(dict, "rules")
+	);
+
 	player->ai = PyObject_Call(PyDict_GetItemString(dict, class), player_args, NULL);
 	Py_DECREF(player_args);
 	
@@ -94,24 +101,8 @@ Card* player_play(Player *player)
 	/* Publish globals to the AI */	
 	game_score_publish();
 	trick_publish(player->trick);
+	player_publish_hand(player);
 	
-	/* Load the hand */
-	PyObject *hand = PyList_New(0);
-	for (l = player->hand->list; l; l = l->next)
-	{
-		Card *card = (Card*)l->data;
-		PyList_Append(hand, Py_BuildValue("(ii)", card->suit, card->rank));
-	} 
-	
-	result = PyObject_CallMethod(player->ai, "set_hand", "O", hand);
-	if (PyErr_Occurred())
-	{
-		PyErr_Print();
-		g_assert_not_reached();
-	}
-	Py_DECREF(hand);
-	Py_DECREF(result);
-
 	/* Call play_card() */
 	result = PyObject_CallMethod(player->ai, "play_card", "");
 	if (PyErr_Occurred())
@@ -144,6 +135,7 @@ Card* player_play(Player *player)
 
 GList* player_select_cards(Player *player)
 {
+	gint passing_direction;
 	GList *l, *cards = NULL;
 	PyObject *result;
 	
@@ -152,26 +144,11 @@ GList* player_select_cards(Player *player)
 	
 	/* Publish globals to the AI */	
 	game_score_publish();
-	
-	/* Load the hand */
-	PyObject *hand = PyList_New(0);
-	for (l = player->hand->list; l; l = l->next)
-	{
-		Card *card = (Card*)l->data;
-		PyList_Append(hand, Py_BuildValue("(ii)", card->suit, card->rank));
-	} 
-	
-	result = PyObject_CallMethod(player->ai, "set_hand", "O", hand);
-	if (PyErr_Occurred())
-	{
-		PyErr_Print();
-		g_assert_not_reached();
-	}
-	Py_DECREF(hand);
-	Py_DECREF(result);
+	player_publish_hand(player);
 
 	/* Call play_card() */
-	result = PyObject_CallMethod(player->ai, "select_cards", NULL);
+	passing_direction = (player->direction + game_pass ) % 4;
+	result = PyObject_CallMethod(player->ai, "select_cards", "(i)", passing_direction);
 	if (PyErr_Occurred())
 	{
 		PyErr_Print();
@@ -205,6 +182,33 @@ GList* player_select_cards(Player *player)
 	return cards;
 }
 
+void player_receive_cards (Player *player, GList *list)
+{
+	/* Add the cards to the hand */
+	cards_hand_add(player->hand, list);
+	player_publish_hand(player);
+	
+	/* call receive_cards() on the player */
+	GList *l;
+	PyObject *result;
+	PyObject *cards = PyList_New(0);
+	
+	for (l = list; l; l = l->next)
+	{
+		Card *card = (Card*)l->data;
+		PyList_Append(cards, Py_BuildValue("(ii)", card->suit, card->rank));
+	} 
+	
+	result = PyObject_CallMethod(player->ai, "receive_cards", "O", cards);
+	if (PyErr_Occurred())
+	{
+		PyErr_Print();
+		g_assert_not_reached();
+	}
+	Py_DECREF(cards);
+	Py_DECREF(result);
+}
+
 /* show the trick to the AI */
 void player_trick_end(Player *player)
 {
@@ -214,6 +218,8 @@ void player_trick_end(Player *player)
 	
 	/* Publish globals to the AI */	
 	trick_publish(player->trick);
+	game_score_publish();
+	player_publish_hand(player);
 	
 	/* Call trick_end() */
 	PyObject *result = PyObject_CallMethod(player->ai, "trick_end", NULL);
@@ -293,6 +299,32 @@ void player_take_trick(Player *player, Trick *trick)
 	{
 		player->cards_taken = g_list_append(player->cards_taken, trick->card[i]);
 	}
+
+	/* Update the score for this round */
+	player->score_round = cards_get_points(player->cards_taken);
+}
+
+/* Show the hand to the player */
+void player_publish_hand (Player *player)
+{
+	GList *l;
+	PyObject *result;
+	
+	PyObject *hand = PyList_New(0);
+	for (l = player->hand->list; l; l = l->next)
+	{
+		Card *card = (Card*)l->data;
+		PyList_Append(hand, Py_BuildValue("(ii)", card->suit, card->rank));
+	} 
+	
+	result = PyObject_CallMethod(player->ai, "set_hand", "O", hand);
+	if (PyErr_Occurred())
+	{
+		PyErr_Print();
+		g_assert_not_reached();
+	}
+	Py_DECREF(hand);
+	Py_DECREF(result);
 }
 
 /* free a player */
